==> roccat-tools-1.0.0.tar.bz2: roccat-tools-1.0.0/ryos/libryos/ryos_keys_extra.c <==
/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Macro Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Macro Public License for more details.
 *
 * You should have received a copy of the GNU Macro Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat/ryos.h"
#include "roccat_helper.h"
#include <string.h>

static gchar const * const keys_extra_name = "keys_extra";

static guint16 ryos_keys_extra_calc_checksum(RyosKeysExtra const *keys_extra) {
	return ROCCAT_BYTESUM_PARTIALLY(keys_extra, RyosKeysExtra, command, checksum);
}

static void ryos_keys_extra_set_checksum(RyosKeysExtra *keys_extra, guint16 new_value) {
	keys_extra->checksum = GUINT16_TO_LE(new_value);
}

static void ryos_keys_extra_finalize(RyosKeysExtra *keys_extra, guint profile_index) {
	keys_extra->command = RYOS_COMMAND_KEYS_EXTRA;
	keys_extra->size = sizeof(RyosKeysExtra);
	keys_extra->profile_index = profile_index;
	ryos_keys_extra_set_checksum(keys_extra, ryos_keys_extra_calc_checksum(keys_extra));
}

gboolean ryos_keys_extra_write(RoccatDevice *ryos, guint profile_index, RyosKeysExtra *keys_extra, GError **error) {
	g_assert(profile_index < RYOS_PROFILE_NUM);
	ryos_keys_extra_finalize(keys_extra, profile_index);
	return roccat_device_write(ryos, keys_extra_name, (gchar const *)keys_extra, sizeof(RyosKeysExtra), error);
}

RyosKeysExtra *ryos_keys_extra_read(RoccatDevice *ryos, guint profile_index, GError **error) {
	RyosKeysExtra *keys_extra;

	g_assert(profile_index < RYOS_PROFILE_NUM);

	roccat_device_lock(ryos);

	if (!ryos_select(ryos, profile_index, RYOS_CONTROL_REQUEST_KEYS_EXTRA, error)) {
		roccat_device_unlock(ryos);
		return NULL;
	}

	keys_extra = (RyosKeysExtra *)roccat_device_read(ryos, keys_extra_name, sizeof(RyosKeysExtra), error);

	roccat_device_unlock(ryos);

	return keys_extra;
}

gboolean ryos_keys_extra_equal(RyosKeysExtra const *left, RyosKeysExtra const *right) {
	gboolean equal;
	equal = ROCCAT_MEMCMP_PARTIALLY(left, right, RyosKeysExtra, capslock, checksum);
	return equal ? FALSE : TRUE;
}

void ryos_keys_extra_copy(RyosKeysExtra *destination, RyosKeysExtra const *source) {
	memcpy(destination, source, sizeof(RyosKeysExtra));
}

==> roccat-tools-1.4.0.tar.bz2: roccat-tools-1.4.0/ryos/libryos/ryos_keys_extra.c <==
/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Macro Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Macro Public License for more details.
 *
 * You should have received a copy of the GNU Macro Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "ryos_keys_extra.h"
#include "ryos_control.h"
#include "roccat_helper.h"
#include "roccat_device_sysfs.h"
#include <string.h>

static gchar const * const keys_extra_name = "keys_extra";

static guint16 ryos_keys_extra_calc_checksum(RyosKeysExtra const *keys_extra) {
	return ROCCAT_BYTESUM_PARTIALLY(keys_extra, RyosKeysExtra, command, checksum);
}

static void ryos_keys_extra_set_checksum(RyosKeysExtra *keys_extra, guint16 new_value) {
	keys_extra->checksum = GUINT16_TO_LE(new_value);
}

static void ryos_keys_extra_finalize(RyosKeysExtra *keys_extra, guint profile_index) {
	keys_extra->command = RYOS_COMMAND_KEYS_EXTRA;
	keys_extra->size = sizeof(RyosKeysExtra);
	keys_extra->profile_index = profile_index;
	ryos_keys_extra_set_checksum(keys_extra, ryos_keys_extra_calc_checksum(keys_extra));
}

gboolean ryos_keys_extra_write(RoccatDevice *ryos, guint profile_index, RyosKeysExtra *keys_extra, GError **error) {
	g_assert(profile_index < RYOS_PROFILE_NUM);
	ryos_keys_extra_finalize(keys_extra, profile_index);
	return roccat_device_sysfs_write(ryos, keys_extra_name, (gchar const *)keys_extra, sizeof(RyosKeysExtra), error);
}

RyosKeysExtra *ryos_keys_extra_read(RoccatDevice *ryos, guint profile_index, GError **error) {
	RyosKeysExtra *keys_extra;

	g_assert(profile_index < RYOS_PROFILE_NUM);

	roccat_device_lock(ryos);

	if (!ryos_select(ryos, profile_index, RYOS_CONTROL_REQUEST_KEYS_EXTRA, error)) {
		roccat_device_unlock(ryos);
		return NULL;
	}

	keys_extra = (RyosKeysExtra *)roccat_device_sysfs_read(ryos, keys_extra_name, sizeof(RyosKeysExtra), error);

	roccat_device_unlock(ryos);

	return keys_extra;
}

gboolean ryos_keys_extra_equal(RyosKeysExtra const *left, RyosKeysExtra const *right) {
	gboolean equal;
	equal = ROCCAT_MEMCMP_PARTIALLY(left, right, RyosKeysExtra, capslock, checksum);
	return equal ? FALSE : TRUE;
}

void ryos_keys_extra_copy(RyosKeysExtra *destination, RyosKeysExtra const *source) {
	memcpy(destination, source, sizeof(RyosKeysExtra));
}
